import { ITaggable } from "aws-cdk-lib";
import { Construct } from "constructs";
/**
 * @stability stable
 */
export interface ITaggableResource extends ITaggable {
    /**
     * The unique identifier (ID) of the account, Organizational unit (OU), parent root or Policy (any type) that you want to tag.
     *
     * @stability stable
     */
    identifier(): string;
}
/**
 * @stability stable
 */
export interface TagResourceProps {
    /**
     * @stability stable
     */
    readonly resource: ITaggableResource;
}
/**
 * Add tags to an AWS Organizations resource to make it easier to identify, organize, and search.
 *
 * @see https://docs.aws.amazon.com/ARG/latest/APIReference/API_Tag.html
 * @stability stable
 */
export declare class TagResource extends Construct {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: TagResourceProps);
}
